@@ -605,8 +605,10 @@ GlassTable::split_root(uint4 split_n)
 
     /* check level overflow - this isn't something that should ever happen
      * but deserves more than an Assert()... */
-    if (level == BTREE_CURSOR_LEVELS) {
-	throw Xapian::DatabaseCorruptError("Btree has grown impossibly large (" STRINGIZE(BTREE_CURSOR_LEVELS) " levels)");
+    if (level == GLASS_BTREE_CURSOR_LEVELS) {
+	throw Xapian::DatabaseCorruptError("Btree has grown impossibly large ("
+					   STRINGIZE(GLASS_BTREE_CURSOR_LEVELS)
+					   " levels)");
     }
 
     uint8_t * q = C[level].init(block_size);
