@@ -1,7 +1,7 @@
 /** @file
  * @brief Remote server for use with ProgClient.
  */
-/* Copyright (C) 2002,2003,2006,2007,2008,2010,2011 Olly Betts
+/* Copyright (C) 2002,2003,2006,2007,2008,2010,2011,2023 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,9 +49,9 @@ static void show_usage() {
     cout << "Usage: " PROG_NAME " [OPTIONS] DATABASE_DIRECTORY...\n\n"
 "Options:\n"
 "  --timeout MSECS         set timeout\n"
-"  --writable              allow updates (only one database directory allowed)\n"
+"  --writable              allow updates\n"
 "  --help                  display this help and exit\n"
-"  --version               output version information and exit" << endl;
+"  --version               output version information and exit\n";
 }
 
 int main(int argc, char **argv)
@@ -68,7 +68,7 @@ int main(int argc, char **argv)
 		show_usage();
 		exit(0);
 	    case OPT_VERSION:
-		cout << PROG_NAME " - " PACKAGE_STRING << endl;
+		cout << PROG_NAME " - " PACKAGE_STRING "\n";
 		exit(0);
 	    case 't':
 		timeout = atoi(optarg) * 1e-3;
@@ -86,12 +86,6 @@ int main(int argc, char **argv)
 	exit(1);
     }
 
-    if (writable && (argc - optind) != 1) {
-	cerr << "Error: only one database directory allowed with '--writable'."
-	     << endl;
-	exit(1);
-    }
-
     /* Unlike xapian-tcpsrv, xapian-progsrv only has a single 'connection'
      * which is established immediately.  So, there is no point in attempting
      * to open the database(s) to check they work - if they can't be opened the
