@@ -1,4 +1,4 @@
-/** @file enquire.h
+/** @file
  * @brief API for running queries
  */
 /* Copyright 1999,2000,2001 BrightStation PLC
@@ -27,7 +27,7 @@
 #define XAPIAN_INCLUDED_ENQUIRE_H
 
 #if !defined XAPIAN_IN_XAPIAN_H && !defined XAPIAN_LIB_BUILD
-# error "Never use <xapian/enquire.h> directly; include <xapian.h> instead."
+# error Never use <xapian/enquire.h> directly; include <xapian.h> instead.
 #endif
 
 #include "xapian/deprecated.h"
@@ -248,7 +248,9 @@ class XAPIAN_VISIBILITY_DEFAULT Enquire {
 	 *  @param spy       The MatchSpy subclass to add.  The caller must
 	 *                   ensure that this remains valid while the Enquire
 	 *                   object remains active, or until @a
-	 *                   clear_matchspies() is called.
+	 *                   clear_matchspies() is called, or else allocate
+	 *                   the MatchSpy object with new and then disown it by
+	 *                   calling spy->release() before passing it in.
 	 */
 	void add_matchspy(MatchSpy * spy);
 
