@@ -1819,3 +1819,19 @@ DEFINE_TESTCASE(unsupportedcheck3, !backend) {
 	TEST_EQUAL(e.get_error_string(), enoent_msg);
     }
 }
+
+// Test handling of corrupt DB with out of range values in the version file.
+// Regression test for #824, fixed in 1.4.25.
+DEFINE_TESTCASE(corruptglass1, glass) {
+    string db_path =
+	test_driver::get_srcdir() + "/testdata/glass_corrupt_db1";
+
+    for (int n = '1'; n <= '3'; ++n) {
+	db_path.back() = n;
+	TEST_EXCEPTION(Xapian::DatabaseCorruptError,
+		       Xapian::Database db(db_path));
+
+	TEST_EXCEPTION(Xapian::DatabaseCorruptError,
+		       Xapian::Database::check(db_path));
+    }
+}
