@@ -265,13 +265,17 @@ DEFINE_TESTCASE(overload1, !backend) {
  *
  *  Currently the OR-subquery case is supported, other operators aren't.
  */
-DEFINE_TESTCASE(possubqueries1, writable) {
-    Xapian::WritableDatabase db = get_writable_database();
-    Xapian::Document doc;
-    doc.add_posting("a", 1);
-    doc.add_posting("b", 2);
-    doc.add_posting("c", 3);
-    db.add_document(doc);
+DEFINE_TESTCASE(possubqueries1, backend) {
+    Xapian::Database db = get_database("possubqueries1",
+				       [](Xapian::WritableDatabase& wdb,
+					  const string&)
+				       {
+					   Xapian::Document doc;
+					   doc.add_posting("a", 1);
+					   doc.add_posting("b", 2);
+					   doc.add_posting("c", 3);
+					   wdb.add_document(doc);
+				       });
 
     Xapian::Query a_or_b(Xapian::Query::OP_OR,
 			 Xapian::Query("a"),
@@ -474,7 +478,7 @@ DEFINE_TESTCASE(wildcard1, backend) {
     const Xapian::Query::op o = Xapian::Query::OP_WILDCARD;
 
     for (auto&& test : wildcard1_testcases) {
-	tout << test.pattern << endl;
+	tout << test.pattern << '\n';
 	auto tend = test.terms + 4;
 	while (tend[-1] == NULL) --tend;
 	bool expect_exception = (tend - test.terms == 4 && tend[-1][0] == '\0');
@@ -541,7 +545,7 @@ DEFINE_TESTCASE(dualprefixwildcard1, backend) {
     Xapian::Query q(Xapian::Query::OP_SYNONYM,
 		    Xapian::Query(Xapian::Query::OP_WILDCARD, "fo"),
 		    Xapian::Query(Xapian::Query::OP_WILDCARD, "Sfo"));
-    tout << q.get_description() << endl;
+    tout << q.get_description() << '\n';
     Xapian::Enquire enq(db);
     enq.set_query(q);
     TEST_EQUAL(enq.get_mset(0, 5).size(), 2);
@@ -763,7 +767,7 @@ gen_subdbwithoutpos1_db(Xapian::WritableDatabase& db, const string&)
     db.add_document(doc);
 }
 
-DEFINE_TESTCASE(subdbwithoutpos1, generated) {
+DEFINE_TESTCASE(subdbwithoutpos1, backend) {
     XFAIL_FOR_BACKEND("remote",
 		      "Known but obscure remote bug which doesn't justify "
 		      "protocol version bump");
