@@ -24,18 +24,16 @@
 
 using namespace std;
 
-std::string
-BackendManagerInMemory::get_dbtype() const
-{
-    return "inmemory";
-}
-
 Xapian::Database
 BackendManagerInMemory::do_get_database(const vector<string>& files)
 {
     Xapian::WritableDatabase wdb(string(), Xapian::DB_BACKEND_INMEMORY);
     index_files_to_database(wdb, files);
-    return std::move(wdb);
+    // This cast avoids a -Wreturn-std-move warning from older clang (seen
+    // with clang 8 and 11; not seen with clang 13).  We can't address this
+    // by adding the suggested std::move() because GCC 13 -Wredundant-move
+    // then warns that the std::move() is redundant!
+    return static_cast<Xapian::Database>(wdb);
 }
 
 Xapian::WritableDatabase
