@@ -80,15 +80,18 @@ class TestRunner {
 	SYNONYMS	= 0x00000080,
 	REPLICAS	= 0x00000100,
 	VALUESTATS	= 0x00000200,
-	GENERATED	= 0x00000400,
-	MULTI		= 0x00000800,
-	SINGLEFILE	= 0x00001000,
-	INMEMORY	= 0x00002000,
-	CHERT		= 0x00004000,
-	GLASS		= 0x00008000,
-	COMPACT		= 0x00010000,
+	MULTI		= 0x00000400,
+	SINGLEFILE	= 0x00000800,
+	INMEMORY	= 0x00001000,
+	GLASS		= 0x00002000,
+	COMPACT		= 0x00004000,
+	CHERT		= 0x00008000,
 	/// Requires get_database_path() or similar.
-	PATH		= 0x00020000,
+	PATH		= 0x00010000,
+	/// TCP variant of remote.
+	REMOTETCP	= 0x00020000,
+	/// Supports Xapian::Database::check().
+	CHECK		= 0x00040000,
     };
 
   public:
